var documenterSearchIndex = {"docs":
[{"location":"api/#API","page":"API","title":"API","text":"","category":"section"},{"location":"api/","page":"API","title":"API","text":"","category":"page"},{"location":"api/#Muon-light","page":"API","title":"Muon light","text":"","category":"section"},{"location":"api/","page":"API","title":"API","text":"LMParameters\ndirectlightfrommuon\nscatteredlightfrommuon\nPMTModel","category":"page"},{"location":"api/#LumenManufaktur.LMParameters","page":"API","title":"LumenManufaktur.LMParameters","text":"The parameter set for light detection.\n\nArguments\n\nminimum_distance: the minimum distance [m] between muon track and PMT\nmodule_radius: radius of the optical module [m] used to implement shadowing of the PMT by the optical module\nlambda_min: minimum wavelength [ns]\nlambda_max: maximum wavelength [ns]\nn: average index of refraction of medium (default: water) corresponding to the group velocity\nlegendre_coefficients: a tuple of two vectors which contain the Legendre coefficients\ndispersion_model: the dispersion model (default: Bailey at 1 atm pressure)\nscattering_model: the scattering model (default: Kopelevich)\nscattering_probability_model: the scattering probability model (default: p00075)\nabsorption_model: the absorption model\n\n\n\n\n\n","category":"type"},{"location":"api/#LumenManufaktur.directlightfrommuon","page":"API","title":"LumenManufaktur.directlightfrommuon","text":"directlightfrommuon(params::LMParameters, pmt::PMTModel, R, θ, ϕ)\n\nReturns the number of photo-electrons from direct Cherenkov light from a muon with a closest distance of R [m] to the PMT and the angles θ [rad] (zenith) and ϕ [rad] (azimuth) with respect to the PMT axis.\n\nArguments\n\nparams: parameters of the setup\npmt: the PMT model\nR: (closest) distance [m] between muon and PMT\nϕ: zenith angle [rad] which is 0 when the PMT points away from the muon track (in x-direction) and rotates counter clockwise to the y-axis when viewed from above, while the z-axis points upwards.\nθ: azimuth angle [rad] which is 0 when the PMT points upwards (along the z-axis) and π/2 when pointing downwards. Between 0 and π/2, the PMT points to the z-axis\n\n\n\n\n\ndirectlightfrommuon(params::LMParameters, pmt::PMTModel, R, θ, ϕ, Δt)\n\nProbability density function for direct Cherenkov light from a muon with a closest distance of R [m] to the PMT, the angles θ [rad] (zenith) and ϕ [rad] (azimuth) with respect to the PMT axis and a time difference Δt [ns] relative to direct Cherenkov light. Returns dP/dt [npe/ns].\n\nArguments\n\nparams: parameters of the setup\npmt: the PMT model\nR: (closest) distance [m] between muon and PMT\nϕ: zenith angle [rad] which is 0 when the PMT points away from the muon track (in x-direction) and rotates counter clockwise to the y-axis when viewed from above, while the z-axis points upwards.\nθ: azimuth angle [rad] which is 0 when the PMT points upwards (along the z-axis) and π/2 when pointing downwards. Between 0 and π/2, the PMT points to the z-axis\nΔt: time difference [ns] relative to the Cherenkov light\n\n\n\n\n\n","category":"function"},{"location":"api/#LumenManufaktur.scatteredlightfrommuon","page":"API","title":"LumenManufaktur.scatteredlightfrommuon","text":"scatteredlightfrommuon(params::LMParameters, pmt::PMTModel, D, cd, θ, ϕ, Δt)\n\nProbability density function for scattered light from muon. Returns [d^2P/dt/dx].\n\nArguments\n\nparams: parameters of the setup\npmt: PMT model\nD: distance between track segment and PMT [m]\ncd: cosine angle of muon direction and track segment - PMT position\nθ: zenith  angle orientation PMT [rad]\nϕ: azimuth angle orientation PMT [rad]\nΔt: time difference relative to direct Cherenkov light\n\n\n\n\n\n","category":"function"},{"location":"api/#LumenManufaktur.PMTModel","page":"API","title":"LumenManufaktur.PMTModel","text":"The PMT model.\n\nArguments\n\nphotocathode_area: the total are of the photocathode [m^2]\nquantum_efficiency: a callable which returns the quantum efficiency for a given wavelength [ns]\nangular_acceptance: a callable which returns the angular acceptance (for values between -1 and 1) for a given wavelength [ns]\n\n\n\n\n\n","category":"type"},{"location":"examples/directlightfrommuon/#Direct-light-from-muon","page":"Direct light from muon","title":"Direct light from muon","text":"","category":"section"},{"location":"examples/directlightfrommuon/","page":"Direct light from muon","title":"Direct light from muon","text":"The following example demonstrates how to calculate the number of photoelectrons for a given environment and PMT.","category":"page"},{"location":"examples/directlightfrommuon/","page":"Direct light from muon","title":"Direct light from muon","text":"using LumenManufaktur","category":"page"},{"location":"examples/directlightfrommuon/","page":"Direct light from muon","title":"Direct light from muon","text":"Let's create the parameters with the defaults but override the dispersion model with the one used in KM3NeT ORCA detectors in the Mediterranean:","category":"page"},{"location":"examples/directlightfrommuon/","page":"Direct light from muon","title":"Direct light from muon","text":"params = LMParameters(dispersion_model=DispersionORCA)","category":"page"},{"location":"examples/directlightfrommuon/","page":"Direct light from muon","title":"Direct light from muon","text":"To calculate the number of photoelectrons from direct light induced by a muon at the closest distance of R=23.5, with a standard KM3NeT PMT pointing in the direction of θ=π and ϕ=π/2, we call directlightfrommuon():","category":"page"},{"location":"examples/directlightfrommuon/","page":"Direct light from muon","title":"Direct light from muon","text":"directlightfrommuon(params, LumenManufaktur.KM3NeTPMT, 23.5, π, π/2)","category":"page"},{"location":"examples/npes_and_zenith_angles/#npe-vs-zenith-angle","page":"npe vs zenith angle","title":"npe vs zenith angle","text":"","category":"section"},{"location":"examples/npes_and_zenith_angles/","page":"npe vs zenith angle","title":"npe vs zenith angle","text":"using CairoMakie\nusing LumenManufaktur\n\nfig = Figure(size = (600, 400));\nax = Axis(\n\tfig[1, 1],\n\txlabel = \"PMT zenith angle [rad]\",\n\tylabel = \"npe\",\n\txgridstyle = :dash, \n\tygridstyle = :dash\n)\nθs = range(-π, π, 1000)\nparams = LMParameters(dispersion_model=BaileyDispersion(240))\npmt = LumenManufaktur.KM3NeTPMT\nfor R in 2:10\n\tlines!(ax, θs, [directlightfrommuon(params, pmt, R, θ, π/2) for θ in θs], label=\"R = $R m\")\nend\naxislegend(; position = :ct)\nfig","category":"page"},{"location":"examples/npes_and_zenith_angles/","page":"npe vs zenith angle","title":"npe vs zenith angle","text":"using CairoMakie\nusing LumenManufaktur\n\nfig = Figure(size = (600, 400));\nax = Axis(\n\tfig[1, 1],\n\txlabel = \"distance between muon and PMT / m\",\n\tylabel = \"npe\",\n\txgridstyle = :dash, \n\tygridstyle = :dash\n)\nRs = range(1, 10, 1000)\nparams = LMParameters(dispersion_model=BaileyDispersion(240))\npmt = LumenManufaktur.KM3NeTPMT\nfor theta_deg in 0:30:180\n    lines!(ax, Rs, [directlightfrommuon(params, pmt, R, deg2rad(theta_deg), π/2) for R in Rs], label=\"θ = $(theta_deg) deg\")\nend\naxislegend(; position = :rt)\nfig","category":"page"},{"location":"#LumenManufaktur.jl","page":"Home","title":"LumenManufaktur.jl","text":"","category":"section"},{"location":"","page":"Home","title":"Home","text":"LumenManufaktur.jl is a software package written in Julia with the aim of providing high-performance routines to calculate probability density functions of the arrival time of light on PMTs induced by muons and showers including production (Cherenkov radiation, photons from energy loss of a muon, shower light), transmission (dispersion, absorption and scattering) and detection (angular acceptance, quantum efficiency, shadowing) of light with a PMT.","category":"page"},{"location":"","page":"Home","title":"Home","text":"The software is written in a way that allows the user to plug in their own models for dispersion, absorption, scattering and also for the quantum efficiency and angular acceptance of PMTs.","category":"page"},{"location":"","page":"Home","title":"Home","text":"The implementation is based on the C++ framework Jpp developed by Maarten de Jong for the KM3NeT neutrino telescope. More details about the underlying physics and models can be found in \"The probability density function of the arrival time of Čerenkov light\", M. de Jong, E. van Campenhout arXiv:2305.19626 [astro-ph.IM].","category":"page"},{"location":"#Installation","page":"Home","title":"Installation","text":"","category":"section"},{"location":"","page":"Home","title":"Home","text":"LumenManufaktur.jl is not an officially registered Julia package but it's available on the KM3NeT Julia registry. To add the KM3NeT Julia registry to your local Julia registry list, follow the instructions there. After that, you can install LumenManufaktur.jl just like any other Julia package:","category":"page"},{"location":"","page":"Home","title":"Home","text":"julia> import Pkg; Pkg.add(\"LumenManufaktur\")","category":"page"},{"location":"#Quickstart","page":"Home","title":"Quickstart","text":"","category":"section"},{"location":"","page":"Home","title":"Home","text":"using LumenManufaktur\n\nparams = LMParameters(dispersion_model=DispersionORCA)\ndirectlightfrommuon(params, LumenManufaktur.KM3NeTPMT, 23.5, π, π/2)","category":"page"}]
}
